==> gromp-0.8.0-py3-none-any.whl: gromp/api/league/__init__.py <==
"""
MIT License

Copyright (c) 2023 Wilhelm Ågren

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

File created: 2023-02-13
Last updated: 2023-02-14
"""

from .ChampionMasteryv4Api import ChampionMasteryv4Api
from .Championv3Api import Championv3Api
from .Clashv1Api import Clashv1Api
from .LeagueExpv4Api import LeagueExpv4Api
from .Leaguev4Api import Leaguev4Api
from .LolChallengesv1Api import LolChallengesv1Api
from .LolStatusv4Api import LolStatusv4Api
from .Matchv5Api import Matchv5Api
from .Spectatorv4Api import Spectatorv4Api
from .Summonerv4Api import Summonerv4Api
from .TournamentStubv4Api import TournamentStubv4Api
from .Tournamentv4Api import Tournamentv4Api

==> gromp-1.0.0-py3-none-any.whl: gromp/api/league/__init__.py <==
"""
MIT License

Copyright (c) 2023 Wilhelm Ågren

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

File created: 2023-02-13
Last updated: 2023-11-04
"""

from .ChampionMasteryv4Api import ChampionMasteryv4Api  # noqa
from .Championv3Api import Championv3Api  # noqa
from .Clashv1Api import Clashv1Api  # noqa
from .LeagueExpv4Api import LeagueExpv4Api  # noqa
from .Leaguev4Api import Leaguev4Api  # noqa
from .LolChallengesv1Api import LolChallengesv1Api  # noqa
from .LolStatusv4Api import LolStatusv4Api  # noqa
from .Matchv5Api import Matchv5Api  # noqa
from .Spectatorv4Api import Spectatorv4Api  # noqa
from .Summonerv4Api import Summonerv4Api  # noqa
from .TournamentStubv4Api import TournamentStubv4Api  # noqa
from .Tournamentv4Api import Tournamentv4Api  # noqa
